@@ -3,13 +3,14 @@ package Unix::Uptime::FreeBSD;
 use warnings;
 use strict;
 
-our $VERSION='0.32';
+our $VERSION='0.3201';
 $VERSION = eval $VERSION;
 
 sub uptime {
     my $class = shift;
     
-    my $boottime = `/sbin/sysctl kern.boottime`;
+    $ENV{PATH} .= ':/usr/local/sbin:/usr/sbin:/sbin';
+    my $boottime = `sysctl kern.boottime`;
     my ($boot_seconds,$boot_useconds) = $boottime =~ /\s+sec\s+=\s+(\d+),\s+usec\s+=\s+(\d+)/;
     return time() - $boot_seconds;
 }
